Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5871)

Unified Diff: chrome/browser/sync/test/integration/enable_disable_test.cc

Issue 14344002: Sync: Turn on full history sync by default. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix use-after-free. Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/sync/sync_prefs_unittest.cc ('k') | chrome/common/chrome_switches.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/test/integration/enable_disable_test.cc
diff --git a/chrome/browser/sync/test/integration/enable_disable_test.cc b/chrome/browser/sync/test/integration/enable_disable_test.cc
index 244550eed4812188237615548c0e55f15029ac79..475b43cfda150909a8892815c1d39886078f8b50 100644
--- a/chrome/browser/sync/test/integration/enable_disable_test.cc
+++ b/chrome/browser/sync/test/integration/enable_disable_test.cc
@@ -111,10 +111,12 @@ IN_PROC_BROWSER_TEST_F(EnableDisableSingleClientTest, DisableOneAtATime) {
ASSERT_TRUE(GetClient(0)->DisableSyncForDatatype(it.Get()));
// AUTOFILL_PROFILE is lumped together with AUTOFILL.
// SESSIONS is lumped together with PROXY_TABS and
// HISTORY_DELETE_DIRECTIVES.
// PRIORITY_PREFERENCES is lumped together with PREFERENCES.
- if (it.Get() == syncer::AUTOFILL_PROFILE || it.Get() == syncer::SESSIONS ||
+ if (it.Get() == syncer::AUTOFILL_PROFILE ||
+ it.Get() == syncer::SESSIONS ||
+ it.Get() == syncer::HISTORY_DELETE_DIRECTIVES ||
it.Get() == syncer::PRIORITY_PREFERENCES) {
continue;
}
@@ -125,14 +127,19 @@ IN_PROC_BROWSER_TEST_F(EnableDisableSingleClientTest, DisableOneAtATime) {
ASSERT_FALSE(DoesTopLevelNodeExist(user_share, it.Get()))
<< syncer::ModelTypeToString(it.Get());
- // AUTOFILL_PROFILE is lumped together with AUTOFILL.
if (it.Get() == syncer::AUTOFILL) {
+ // AUTOFILL_PROFILE is lumped together with AUTOFILL.
+ ASSERT_FALSE(DoesTopLevelNodeExist(user_share, syncer::AUTOFILL_PROFILE));
+ } else if (it.Get() == syncer::TYPED_URLS) {
ASSERT_FALSE(DoesTopLevelNodeExist(user_share,
- syncer::AUTOFILL_PROFILE));
- } else if (it.Get() == syncer::HISTORY_DELETE_DIRECTIVES ||
- it.Get() == syncer::PROXY_TABS) {
- ASSERT_FALSE(DoesTopLevelNodeExist(user_share,
- syncer::SESSIONS));
+ syncer::HISTORY_DELETE_DIRECTIVES));
+ // SESSIONS should be enabled only if PROXY_TABS is.
+ ASSERT_EQ(GetClient(0)->IsTypePreferred(syncer::PROXY_TABS),
+ DoesTopLevelNodeExist(user_share, syncer::SESSIONS));
+ } else if (it.Get() == syncer::PROXY_TABS) {
+ // SESSIONS should be enabled only if TYPED_URLS is.
+ ASSERT_EQ(GetClient(0)->IsTypePreferred(syncer::TYPED_URLS),
+ DoesTopLevelNodeExist(user_share, syncer::SESSIONS));
} else if (it.Get() == syncer::PREFERENCES) {
ASSERT_FALSE(DoesTopLevelNodeExist(user_share,
syncer::PRIORITY_PREFERENCES));
@@ -111,10 +111,12 @@ IN_PROC_BROWSER_TEST_F(EnableDisableSingleClientTest, DisableOneAtATime) {
ASSERT_TRUE(GetClient(0)->DisableSyncForDatatype(it.Get()));
// AUTOFILL_PROFILE is lumped together with AUTOFILL.
- // SESSIONS is lumped together with PROXY_TABS and
- // HISTORY_DELETE_DIRECTIVES.
+ // SESSIONS is lumped together with PROXY_TABS and TYPED_URLS.
+ // HISTORY_DELETE_DIRECTIVES is lumped together with TYPED_URLS.
// PRIORITY_PREFERENCES is lumped together with PREFERENCES.
« no previous file with comments | « chrome/browser/sync/sync_prefs_unittest.cc ('k') | chrome/common/chrome_switches.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698